<div align="center">
  <a href="https://docs.iamai.is-a.dev/"><img src="https://mirror.ghproxy.com/raw.githubusercontent.com/retrofor/iamai/master/docs/_static/logo.png" width="200" height="200" alt="logo"></a>

# iamai-adapter-kook

**Kook 平台适配**

</div>
